==> lombok_1.18.24.orig.tar.xz: lombok-1.18.24/test/transform/resource/after-ecj/GetterAlreadyExists.java <==
class Getter1 {
  @lombok.Getter boolean foo;
  Getter1() {
    super();
  }
  boolean hasFoo() {
    return true;
  }
  public @java.lang.SuppressWarnings("all") boolean isFoo() {
    return this.foo;
  }
}
class Getter2 {
  @lombok.Getter boolean foo;
  Getter2() {
    super();
  }
  boolean isFoo() {
    return true;
  }
}
class Getter3 {
  @lombok.Getter boolean foo;
  Getter3() {
    super();
  }
  boolean getFoo() {
    return true;
  }
}
class Getter4 {
  @lombok.Getter String foo;
  Getter4() {
    super();
  }
  String hasFoo() {
    return null;
  }
  public @java.lang.SuppressWarnings("all") String getFoo() {
    return this.foo;
  }
}
class Getter5 {
  @lombok.Getter String foo;
  Getter5() {
    super();
  }
  String isFoo() {
    return null;
  }
  public @java.lang.SuppressWarnings("all") String getFoo() {
    return this.foo;
  }
}
class Getter6 {
  @lombok.Getter String foo;
  Getter6() {
    super();
  }
  String getFoo() {
    return null;
  }
}
class Getter7 {
  @lombok.Getter String foo;
  Getter7() {
    super();
  }
  boolean hasFoo() {
    return false;
  }
  public @java.lang.SuppressWarnings("all") String getFoo() {
    return this.foo;
  }
}
class Getter8 {
  @lombok.Getter String foo;
  Getter8() {
    super();
  }
  boolean isFoo() {
    return false;
  }
  public @java.lang.SuppressWarnings("all") String getFoo() {
    return this.foo;
  }
}
class Getter9 {
  @lombok.Getter String foo;
  Getter9() {
    super();
  }
  boolean getFoo() {
    return false;
  }
}
class Getter10 {
  @lombok.Getter boolean foo;
  Getter10() {
    super();
  }
  static boolean hasFoo() {
    return false;
  }
  public @java.lang.SuppressWarnings("all") boolean isFoo() {
    return this.foo;
  }
}
class Getter11 {
  @lombok.Getter boolean foo;
  Getter11() {
    super();
  }
  static boolean isFoo() {
    return false;
  }
}
class Getter12 {
  @lombok.Getter boolean foo;
  Getter12() {
    super();
  }
  static boolean getFoo() {
    return false;
  }
}
class Getter13 {
  @lombok.Getter String foo;
  Getter13() {
    super();
  }
  static boolean hasFoo() {
    return false;
  }
  public @java.lang.SuppressWarnings("all") String getFoo() {
    return this.foo;
  }
}
class Getter14 {
  @lombok.Getter String foo;
  Getter14() {
    super();
  }
  static boolean isFoo() {
    return false;
  }
  public @java.lang.SuppressWarnings("all") String getFoo() {
    return this.foo;
  }
}
class Getter15 {
  @lombok.Getter String foo;
  Getter15() {
    super();
  }
  static boolean getFoo() {
    return false;
  }
}
class Getter16 {
  @lombok.Getter String foo;
  Getter16() {
    super();
  }
  static String hasFoo() {
    return "";
  }
  public @java.lang.SuppressWarnings("all") String getFoo() {
    return this.foo;
  }
}
class Getter17 {
  @lombok.Getter String foo;
  Getter17() {
    super();
  }
  static String isFoo() {
    return "";
  }
  public @java.lang.SuppressWarnings("all") String getFoo() {
    return this.foo;
  }
}
class Getter18 {
  @lombok.Getter String foo;
  Getter18() {
    super();
  }
  static String getFoo() {
    return "";
  }
}

==> lombok_1.18.42.orig.tar.xz: lombok-1.18.42/test/transform/resource/after-ecj/GetterAlreadyExists.java <==
class Getter1 {
  @lombok.Getter boolean foo;
  Getter1() {
    super();
  }
  boolean hasFoo() {
    return true;
  }
  public @java.lang.SuppressWarnings("all") @lombok.Generated boolean isFoo() {
    return this.foo;
  }
}
class Getter2 {
  @lombok.Getter boolean foo;
  Getter2() {
    super();
  }
  boolean isFoo() {
    return true;
  }
}
class Getter3 {
  @lombok.Getter boolean foo;
  Getter3() {
    super();
  }
  boolean getFoo() {
    return true;
  }
}
class Getter4 {
  @lombok.Getter String foo;
  Getter4() {
    super();
  }
  String hasFoo() {
    return null;
  }
  public @java.lang.SuppressWarnings("all") @lombok.Generated String getFoo() {
    return this.foo;
  }
}
class Getter5 {
  @lombok.Getter String foo;
  Getter5() {
    super();
  }
  String isFoo() {
    return null;
  }
  public @java.lang.SuppressWarnings("all") @lombok.Generated String getFoo() {
    return this.foo;
  }
}
class Getter6 {
  @lombok.Getter String foo;
  Getter6() {
    super();
  }
  String getFoo() {
    return null;
  }
}
class Getter7 {
  @lombok.Getter String foo;
  Getter7() {
    super();
  }
  boolean hasFoo() {
    return false;
  }
  public @java.lang.SuppressWarnings("all") @lombok.Generated String getFoo() {
    return this.foo;
  }
}
class Getter8 {
  @lombok.Getter String foo;
  Getter8() {
    super();
  }
  boolean isFoo() {
    return false;
  }
  public @java.lang.SuppressWarnings("all") @lombok.Generated String getFoo() {
    return this.foo;
  }
}
class Getter9 {
  @lombok.Getter String foo;
  Getter9() {
    super();
  }
  boolean getFoo() {
    return false;
  }
}
class Getter10 {
  @lombok.Getter boolean foo;
  Getter10() {
    super();
  }
  static boolean hasFoo() {
    return false;
  }
  public @java.lang.SuppressWarnings("all") @lombok.Generated boolean isFoo() {
    return this.foo;
  }
}
class Getter11 {
  @lombok.Getter boolean foo;
  Getter11() {
    super();
  }
  static boolean isFoo() {
    return false;
  }
}
class Getter12 {
  @lombok.Getter boolean foo;
  Getter12() {
    super();
  }
  static boolean getFoo() {
    return false;
  }
}
class Getter13 {
  @lombok.Getter String foo;
  Getter13() {
    super();
  }
  static boolean hasFoo() {
    return false;
  }
  public @java.lang.SuppressWarnings("all") @lombok.Generated String getFoo() {
    return this.foo;
  }
}
class Getter14 {
  @lombok.Getter String foo;
  Getter14() {
    super();
  }
  static boolean isFoo() {
    return false;
  }
  public @java.lang.SuppressWarnings("all") @lombok.Generated String getFoo() {
    return this.foo;
  }
}
class Getter15 {
  @lombok.Getter String foo;
  Getter15() {
    super();
  }
  static boolean getFoo() {
    return false;
  }
}
class Getter16 {
  @lombok.Getter String foo;
  Getter16() {
    super();
  }
  static String hasFoo() {
    return "";
  }
  public @java.lang.SuppressWarnings("all") @lombok.Generated String getFoo() {
    return this.foo;
  }
}
class Getter17 {
  @lombok.Getter String foo;
  Getter17() {
    super();
  }
  static String isFoo() {
    return "";
  }
  public @java.lang.SuppressWarnings("all") @lombok.Generated String getFoo() {
    return this.foo;
  }
}
class Getter18 {
  @lombok.Getter String foo;
  Getter18() {
    super();
  }
  static String getFoo() {
    return "";
  }
}
